@@ -29,7 +29,7 @@
 #include <algorithm>
 #include <iostream>
 
-namespace unity {
+namespace lomiri {
 namespace indicator {
 namespace transfer {
 
@@ -1006,4 +1006,4 @@ DMSource::get_model()
 
 } // namespace transfer
 } // namespace indicator
-} // namespace unity
+} // namespace lomiri
