@@ -26,7 +26,7 @@
 #include <glib/gi18n.h>
 #include <gio/gio.h>
 
-namespace unity {
+namespace lomiri {
 namespace indicator {
 namespace transfer {
 
@@ -1026,5 +1026,5 @@ const core::Signal<>& GMenuView::name_lost() const
 
 } // namespace transfer
 } // namespace indicator
-} // namespace unity
+} // namespace lomiri
 
